%global pkg qla2xxx

%global kernel_version_min 4.18.0-305.el8

# To pick a specific kernel use `--define "kernel_version 4.18.0-315.el8"`
# Otherwise the latest installed kernel-devel version later than
# %%{kernel_version_min} will be used.

%global kernel_version_latest %({ echo %{kernel_version_min}; rpm --query kernel-devel --queryformat '%%{VERSION}-%%{RELEASE}\\\n' | grep -v "package kernel-devel is not installed"; } | sort -V | sed -e '0,/^%{kernel_version_min}$/d' | tail -n 1)

%if "%{kernel_version_latest}" != ""
%{!?kernel_version:%{expand:%%global kernel_version %{kernel_version_latest}}}
%endif

%global _use_internal_dependency_generator 0
%global __find_requires %{nil}
%global __find_provides /usr/lib/rpm/find-provides

%global debug_package %{nil}

%global __spec_install_post \
  %{?__debug_package:%{__debug_install_post}} \
  %{__arch_install_post} \
  %{__os_install_post} \
  %{__mod_compress_install_post}

%global __mod_compress_install_post find %{buildroot}/lib/modules -type f -name \*.ko -exec xz \{\} \\;


Name:             kmod-%{pkg}
Version:          4.18.0
Release:          305.12.1%{?dist}
Summary:          QLogic Fibre Channel HBA (%{pkg}) driver

License:          GPLv2
URL:              https://www.kernel.org/

Source0:          %{pkg}-%{kernel_version_min}.tar.xz
Patch1:           0001-add-deprecated-ids.patch

ExclusiveArch:    x86_64 aarch64

BuildRequires:    elfutils-libelf-devel
BuildRequires:    gcc
BuildRequires:    kmod
BuildRequires:    make
BuildRequires:    redhat-rpm-config
BuildRequires:    xz

%{!?kernel_version:
BuildRequires:    kernel-devel >= %{kernel_version_min}
}

%{?kernel_version:
BuildRequires:    kernel-devel = %{kernel_version}
BuildRequires:    kernel-devel-uname-r = %{kernel_version}.%{_arch}

Requires:         kernel-core = %{kernel_version}
Requires:         kernel-core-uname-r = %{kernel_version}.%{_arch}
Requires:         kernel-modules = %{kernel_version}
Requires:         kernel-modules-uname-r = %{kernel_version}.%{_arch}

Provides:         installonlypkg(kernel-module)
Provides:         %{name}-%{kernel_version}.%{_arch} = %{?epoch:%{epoch}:}%{version}-%{release}
}

Requires(post):   /usr/sbin/depmod
Requires(postun): /usr/sbin/depmod

Requires(post):   /usr/bin/dracut
Requires(postun): /usr/bin/dracut


%description
This package provides the QLogic Fibre Channel HBA (%{pkg}) driver. Compared to
the in-kernel driver this driver re-enables support for deprecated adapters:

- 0x1077:0x2100: QLogic ISP2100
- 0x1077:0x2200: QLogic ISP2200
- 0x1077:0x2300: QLogic ISP2300
- 0x1077:0x2312: QLogic ISP2312
- 0x1077:0x2322: QLogic ISP2322
- 0x1077:0x2422: QLogic ISP2422
- 0x1077:0x2432: QLogic ISP2432
- 0x1077:0x5422: QLogic ISP5422
- 0x1077:0x5432: QLogic ISP5432 / QLE220
- 0x1077:0x6312: QLogic ISP6312
- 0x1077:0x6322: QLogic ISP6322
- 0x1077:0x8001: QLogic ISP8001 / QLE81xx
- 0x1077:0x8021: QLogic ISP8021 / QLE82xx
- 0x1077:0x8044: QLogic ISP8044 / QLE84xx
- 0x1077:0x8432: QLogic ISP8432 / QLE8000
- 0x1077:0xF001: QLogic ISPF001 / QLE10000


%prep
%autosetup -p1 -n %{pkg}-%{kernel_version_min}


%build
pushd src
%{__make} -C /usr/src/kernels/%{kernel_version}.%{_arch} %{?_smp_mflags} M=$PWD modules
popd


%install
%{__install} -D -t %{buildroot}/lib/modules/%{kernel_version}.%{_arch}/extra/drivers/scsi/%{pkg} src/%{pkg}.ko

# Make .ko objects temporarily executable for automatic stripping
find %{buildroot}/lib/modules -type f -name \*.ko -exec chmod u+x \{\} \+


%clean
%{__rm} -rf %{buildroot}


%post
mkdir -p %{_localstatedir}/lib/rpm-state/sig-kmods
touch %{_localstatedir}/lib/rpm-state/sig-kmods/%{kernel_version}.%{_arch}


%preun
mkdir -p %{_localstatedir}/lib/rpm-state/sig-kmods
touch %{_localstatedir}/lib/rpm-state/sig-kmods/%{kernel_version}.%{_arch}


%postun
if [ -f %{_localstatedir}/lib/rpm-state/sig-kmods/%{kernel_version}.%{_arch} ]
then
    if [ -f /lib/modules/%{kernel_version}.%{_arch}/System.map ]
    then
        /usr/sbin/depmod -aeF /lib/modules/%{kernel_version}.%{_arch}/System.map %{kernel_version}.%{_arch}
    fi

    if [ -f /boot/initramfs-%{kernel_version}.%{_arch}.img ]
    then
        if /usr/bin/dracut -f --rebuild /boot/initramfs-%{kernel_version}.%{_arch}.img /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew %{kernel_version}.%{_arch}
        then
            if ! cmp -s /boot/initramfs-%{kernel_version}.%{_arch}.img /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew
            then
                mv /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew /boot/initramfs-%{kernel_version}.%{_arch}.img
            else
                rm -f /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew
            fi
        fi
    fi

    rm -f %{_localstatedir}/lib/rpm-state/sig-kmods/%{kernel_version}.%{_arch}
    rmdir --ignore-fail-on-non-empty %{_localstatedir}/lib/rpm-state/sig-kmods
fi


%posttrans
if [ -f %{_localstatedir}/lib/rpm-state/sig-kmods/%{kernel_version}.%{_arch} ]
then
    if [ -f /lib/modules/%{kernel_version}.%{_arch}/System.map ]
    then
        /usr/sbin/depmod -aeF /lib/modules/%{kernel_version}.%{_arch}/System.map %{kernel_version}.%{_arch}
    fi

    if [ -f /boot/initramfs-%{kernel_version}.%{_arch}.img ]
    then
        if /usr/bin/dracut -f --rebuild /boot/initramfs-%{kernel_version}.%{_arch}.img /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew %{kernel_version}.%{_arch}
        then
            if ! cmp -s /boot/initramfs-%{kernel_version}.%{_arch}.img /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew
            then
                mv /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew /boot/initramfs-%{kernel_version}.%{_arch}.img
            else
                rm -f /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew
            fi
        fi
    fi

    rm -f %{_localstatedir}/lib/rpm-state/sig-kmods/%{kernel_version}.%{_arch}
    rmdir --ignore-fail-on-non-empty %{_localstatedir}/lib/rpm-state/sig-kmods
fi


%files
%defattr(644,root,root,755)
/lib/modules/%{kernel_version}.%{_arch}
%license COPYING


%changelog
* Wed Aug 11 2021 Peter Georg <peter.georg@physik.uni-regensburg.de> - 4.18.0-305.12.1
- Rebuild for 4.18.0-305.12.1.el8_4

* Wed Aug 11 2021 Peter Georg <peter.georg@physik.uni-regensburg.de> - 4.18.0-305
- Initial version
